@@ -46,9 +46,7 @@ from The Open Group.
 
 # include	"dm_socket.h"
 
-# ifndef X_NO_SYS_UN
-#  include	<sys/un.h>
-# endif
+# include	<sys/un.h>
 # include	<netdb.h>
 # include	<arpa/inet.h>
 
@@ -74,14 +72,11 @@ static void request_respond (struct sockaddr *from, int fromlen, int length, int
 static void send_accept (struct sockaddr *to, int tolen, CARD32 sessionID, ARRAY8Ptr authenticationName, ARRAY8Ptr authenticationData, ARRAY8Ptr authorizationName, ARRAY8Ptr authorizationData, int fd);
 static void send_alive (struct sockaddr *from, int fromlen, int length, int fd);
 static void send_decline (struct sockaddr *to, int tolen, ARRAY8Ptr authenticationName, ARRAY8Ptr authenticationData, ARRAY8Ptr status, int fd);
-static void send_failed (struct sockaddr *from, int fromlen, char *name, CARD32 sessionID, char *reason, int fd);
+static void send_failed (struct sockaddr *from, int fromlen, const char *name, CARD32 sessionID, const char *reason, int fd);
 static void send_refuse (struct sockaddr *from, int fromlen, CARD32 sessionID, int fd);
 static void send_unwilling (struct sockaddr *from, int fromlen, ARRAY8Ptr authenticationName, ARRAY8Ptr status, int fd);
 static void send_willing (struct sockaddr *from, int fromlen, ARRAY8Ptr authenticationName, ARRAY8Ptr status, int fd);
 
-# ifdef STREAMSCONN
-int	xdmcpFd = -1;
-# endif
 int	chooserFd = -1;
 # if defined(IPv6) && defined(AF_INET6)
 int	chooserFd6 = -1;
@@ -95,14 +90,6 @@ int	WellKnownSocketsMax;
 void
 DestroyWellKnownSockets (void)
 {
-# ifdef STREAMSCONN
-    if (xdmcpFd != -1)
-    {
-	close (xdmcpFd);
-	FD_CLR(xdmcpFd, &WellKnownSocketsMask);
-	xdmcpFd = -1;
-    }
-# endif
     if (chooserFd != -1)
     {
 	close (chooserFd);
@@ -137,9 +124,6 @@ int
 AnyWellKnownSockets (void)
 {
     return
-# ifdef STREAMS_CONN
-      xdmcpFd != -1 ||
-# endif
 # if defined(IPv6) && defined(AF_INET6)
       chooserFd6 != -1 ||
 # endif
@@ -160,8 +144,6 @@ sendForward (
 # endif
 # if defined(IPv6) && defined(AF_INET6)
     struct sockaddr_in6	    in6_addr;
-# endif
-# ifdef AF_DECnet
 # endif
     struct sockaddr	    *addr;
     int			    addrlen;
@@ -179,7 +161,7 @@ sendForward (
 	in_addr.sin_port = htons ((short) XDM_UDP_PORT);
 	if (address->length != 4)
 	    return;
-	memmove( (char *) &in_addr.sin_addr, address->data, address->length);
+	memcpy(&in_addr.sin_addr, address->data, address->length);
 	addrlen = sizeof (struct sockaddr_in);
 	break;
 # endif
@@ -194,12 +176,9 @@ sendForward (
 	in6_addr.sin6_port = htons ((short) XDM_UDP_PORT);
 	if (address->length != 16)
 	    return;
-	memmove( (char *) &in6_addr.sin6_addr, address->data, address->length);
+	memcpy(&in6_addr.sin6_addr, address->data, address->length);
 	addrlen = sizeof (struct sockaddr_in6);
 	break;
-# endif
-# ifdef AF_DECnet
-    case FamilyDECnet:
 # endif
     default:
 	return;
@@ -220,12 +199,12 @@ ClientAddress (
 
     data = NetaddrPort((XdmcpNetaddr) from, &length);
     XdmcpAllocARRAY8 (port, length);
-    memmove( port->data, data, length);
+    memcpy(port->data, data, length);
     port->length = length;
 
     family = ConvertAddr((XdmcpNetaddr) from, &length, &data);
     XdmcpAllocARRAY8 (addr, length);
-    memmove( addr->data, data, length);
+    memcpy(addr->data, data, length);
     addr->length = length;
 
     *type = family;
@@ -251,6 +230,10 @@ all_query_respond (
 # endif
 
     family = ConvertAddr((XdmcpNetaddr) from, &length, (char **)&(addr.data));
+    if (family < 0) {
+	Debug("all_query_respond: ConvertAddr failed: conntype=%d\n", family);
+	return;
+    }
     addr.length = length;	/* convert int to short */
     if (debugLevel > 0) {
 # if defined(IPv6) && defined(AF_INET6)
@@ -270,8 +253,6 @@ all_query_respond (
 	Debug("all_query_respond: conntype=%d, addr=%s, len=%d\n",
 	    family, addrstring, addr.length);
     }
-    if (family < 0)
-	return;
     connectionType = family;
 
     if (type == INDIRECT_QUERY)
@@ -411,28 +392,14 @@ WaitForSomething (void)
 		nready, Rescan, ChildReady);
 	if (nready > 0)
 	{
-# ifdef STREAMSCONN
-	    if (xdmcpFd >= 0 && FD_ISSET (xdmcpFd, &reads))
-		ProcessRequestSocket (xdmcpFd);
-# endif
 	    if (chooserFd >= 0 && FD_ISSET (chooserFd, &reads))
 	    {
-# ifdef ISC
-	        if (!ChildReady) {
-	           WaitForSomething ();
-                } else
-# endif
 		ProcessChooserSocket (chooserFd);
 		FD_CLR(chooserFd, &reads);
 	    }
 # if defined(IPv6) && defined(AF_INET6)
 	    if (chooserFd6 >= 0 && FD_ISSET (chooserFd6, &reads))
 	    {
-#  ifdef ISC
-	        if (!ChildReady) {
-	           WaitForSomething ();
-                } else
-#  endif
 		ProcessChooserSocket (chooserFd6);
 		FD_CLR(chooserFd6, &reads);
 	    }
@@ -713,10 +680,6 @@ NetworkAddressToName(
 	    return name;
 	}
 # endif /* IPv6 */
-# ifdef DNET
-    case FamilyDECnet:
-	return NULL;
-# endif /* DNET */
     default:
 	return NULL;
     }
@@ -777,8 +740,8 @@ forward_respond (
 		    in_addr.sin_len = sizeof(in_addr);
 #  endif
 		    in_addr.sin_family = AF_INET;
-		    memmove( &in_addr.sin_addr, clientAddress.data, 4);
-		    memmove( (char *) &in_addr.sin_port, clientPort.data, 2);
+		    memcpy(&in_addr.sin_addr, clientAddress.data, 4);
+		    memcpy(&in_addr.sin_port, clientPort.data, 2);
 		    client = (struct sockaddr *) &in_addr;
 		    clientlen = sizeof (in_addr);
 		    all_query_respond (client, clientlen, &authenticationNames,
@@ -802,7 +765,7 @@ forward_respond (
 #  endif
 		    in6_addr.sin6_family = AF_INET6;
 		    if (clientAddress.length == 16) {
-			memmove(in6_addr.sin6_addr.s6_addr, clientAddress.data, 16);
+			memcpy(in6_addr.sin6_addr.s6_addr, clientAddress.data, 16);
 		    } else {
 			/* If the client wants to forward the xdm server to an
 			   ipv4 hosts it sends an ipv4 address in the forward
@@ -817,9 +780,10 @@ forward_respond (
 			*/
 			in6_addr.sin6_addr.s6_addr[10] = 0xff;
 			in6_addr.sin6_addr.s6_addr[11] = 0xff;
-			memmove(in6_addr.sin6_addr.s6_addr + 12, clientAddress.data, 4);
+			memcpy(in6_addr.sin6_addr.s6_addr + 12,
+                               clientAddress.data, 4);
 		    }
-		    memmove((char *) &in6_addr.sin6_port, clientPort.data, 2);
+		    memcpy(&in6_addr.sin6_port, clientPort.data, 2);
 		    client = (struct sockaddr *) &in6_addr;
 		    clientlen = sizeof (in6_addr);
 		    all_query_respond (client, clientlen, &authenticationNames,
@@ -836,7 +800,8 @@ forward_respond (
 			goto badAddress;
 		    bzero ((char *) &un_addr, sizeof (un_addr));
 		    un_addr.sun_family = AF_UNIX;
-		    memmove( un_addr.sun_path, clientAddress.data, clientAddress.length);
+		    memcpy(un_addr.sun_path, clientAddress.data,
+                           clientAddress.length);
 		    un_addr.sun_path[clientAddress.length] = '\0';
 		    client = (struct sockaddr *) &un_addr;
 #  if defined(BSD44SOCKETS) && defined(UNIXCONN)
@@ -849,14 +814,6 @@ forward_respond (
 			       FORWARD_QUERY, fd);
 		}
 		break;
-# endif
-# ifdef AF_CHAOS
-	    case AF_CHAOS:
-		goto badAddress;
-# endif
-# ifdef AF_DECnet
-	    case AF_DECnet:
-		goto badAddress;
 # endif
 	    }
 	}
@@ -1224,7 +1181,7 @@ manage (
 	    }
 	    if (displayClass.length)
 	    {
-		memmove( class, displayClass.data, displayClass.length);
+		memcpy(class, displayClass.data, displayClass.length);
 		class[displayClass.length] = '\0';
 	    }
 	    else
@@ -1239,7 +1196,7 @@ manage (
 		  "out of memory", fd);
 		goto abort;
 	    }
-	    memmove( from_save, from, fromlen);
+	    memcpy(from_save, from, fromlen);
 	    d = NewDisplay (name, class);
 	    if (!d)
 	    {
@@ -1300,7 +1257,7 @@ abort:
 void
 SendFailed (
     struct display  *d,
-    char	    *reason)
+    const char	    *reason)
 {
     Debug ("Display start failed, sending Failed\n");
     send_failed ((struct sockaddr *)(d->from), d->fromlen, d->name,
@@ -1311,9 +1268,9 @@ static void
 send_failed (
     struct sockaddr *from,
     int		    fromlen,
-    char	    *name,
+    const char	    *name,
     CARD32	    sessionID,
-    char	    *reason,
+    const char	    *reason,
     int		    fd)
 {
     static char	buf[256];
@@ -1416,7 +1373,7 @@ NetworkAddressToHostname (
 # else
 	    char dotted[20];
 # endif
-	    char *local_name = "";
+	    const char *local_name = "";
 	    int af_type;
 
 # if defined(IPv6) && defined(AF_INET6)
@@ -1496,106 +1453,10 @@ NetworkAddressToHostname (
 	    name = strdup (local_name);
 	    break;
 	}
-# ifdef DNET
-    case FamilyDECnet:
-	break;
-# endif /* DNET */
     default:
 	break;
     }
     return name;
 }
 
-# if 0
-static int
-HostnameToNetworkAddress (
-char	    *name,
-CARD16	    connectionType,
-ARRAY8Ptr   connectionAddress)
-{
-    switch (connectionType)
-    {
-    case FamilyInternet:
-	{
-	    struct hostent	*hostent;
-
-	    hostent = gethostbyname (name);
-	    if (!hostent)
-		return FALSE;
-	    if (!XdmcpAllocARRAY8 (connectionAddress, hostent->h_length))
-		return FALSE;
-	    memmove( connectionAddress->data, hostent->h_addr, hostent->h_length);
-	    return TRUE;
-	}
-#  ifdef DNET
-    case FamilyDECnet:
-	return FALSE;
-#  endif
-    }
-    return FALSE;
-}
-
-/*
- * converts a display name into a network address, using
- * the same rules as XOpenDisplay (algorithm cribbed from there)
- */
-static int
-NameToNetworkAddress(
-char	    *name,
-CARD16Ptr   connectionTypep,
-ARRAY8Ptr   connectionAddress,
-CARD16Ptr   displayNumber)
-{
-    char    *colon, *display_number;
-    char    hostname[1024];
-    int	    dnet = FALSE;
-    CARD16  number;
-    CARD16  connectionType;
-
-    colon = strchr(name, ':');
-    if (!colon)
-	return FALSE;
-    if (colon != name)
-    {
-	if (colon - name > sizeof (hostname))
-	    return FALSE;
-	strncpy (hostname, name, colon - name);
-	hostname[colon - name] = '\0';
-    }
-    else
-    {
-	strcpy (hostname, localHostname ());
-    }
-    if (colon[1] == ':')
-    {
-	dnet = TRUE;
-	colon++;
-    }
-#  ifndef DNETCONN
-    if (dnet)
-	return FALSE;
-#  endif
-    display_number = colon + 1;
-    while (*display_number && *display_number != '.')
-    {
-	if (!isascii (*display_number) || !isdigit(*display_number))
-	    return FALSE;
-    }
-    if (display_number == colon + 1)
-	return FALSE;
-    number = atoi (colon + 1);
-#  ifdef DNETCONN
-    if (dnet)
-	connectionType = FamilyDECnet;
-    else
-#  endif
-	connectionType = FamilyInternet;
-    if (!HostnameToNetworkAddress (hostname, connectionType, connectionAddress))
-	return FALSE;
-    *displayNumber = number;
-    *connectionTypep = connectionType;
-    return TRUE;
-}
-# endif
-
 #endif /* XDMCP */
